]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - lib.sh
lib.sh: Improve installed() to work with more which.
[config/dotfiles.git] / lib.sh
diff --git a/lib.sh b/lib.sh
index fbef907d330bd62aec6bf67a5d0b4c237c267159..49ce998660f3132b0b33d2bbca86e5ac936719f6 100644 (file)
--- a/lib.sh
+++ b/lib.sh
@@ -4,14 +4,14 @@
 
 
 # csh gives the error "Unknown colorls variable `su'." when used with newer
-# options supported by zsh or GNU ls.
+# options supported by Zsh or GNU ls.
 unset LS_COLORS
 
 
 # Check if the given program is installed. Returns 0 if it exists, 1
 # otherwise; so it can be used in if.
 installed() {
-    which $1 | grep -E '^/' > /dev/null
+    which $1 2>&1 | perl -ne 'if (not m{^/}) { exit 1 }'
 }
 
 # Prints the current OS. Supported are Debian (debian), Gentoo (gentoo) and
@@ -30,7 +30,7 @@ os() {
     fi
 }
 
-# Creates a symbolic link for file $1 in dirname of $2 with name of basenmae
+# Creates a symbolic link for file $1 in dirname of $2 with name of basename
 # $2.
 #
 # `./link.sh example ~/.examplerc` creates a symbolic link to example
@@ -39,7 +39,7 @@ link() {
     # Get all necessary paths.
     pwd=`pwd`
     base=`dirname "$2"`
-    source=`echo -n "$pwd/$1" | sed "s|$base/||"`
+    source=`echo "$pwd/$1" | sed "s|$base/||"`
     target=`basename "$2"`
 
     # Go to the directory where the link is going to be created.
@@ -71,7 +71,7 @@ link() {
 
 # Write a warning to $1 to make clear it should not be modified. $2 is the
 # source for the generated file. Also print a message to stdout that the file
-# $1 was generated from $2 using the command $3.
+# $1 was generated from $2 using the command $3 with options $4.
 warning() {
     echo "###################################" > $1
     echo "# WARNING! DO NOT EDIT THIS FILE! #" >> $1
@@ -80,19 +80,29 @@ warning() {
     echo "# It was generated from $2 on `date`." >> $1
     echo >> $1
 
+    # Display given options if there were any (Zsh has a problem with $options
+    # as variable name).
+    option=
+    if [ -n "$4" ]; then
+        option=" with options '$4'"
+    fi
     # Write message to stdout.
-    echo "$3: generating '$1' from '$2'"
+    echo "$3: generating '$1' from '$2'$option"
+
+    unset option
 }
 
-# Generate a file using several methods. A warning is automatically added to
-# the created file and a message printed to stdout through warning().
+# Generate a file using several methods. A warning not to edit it is
+# automatically added to the created file and a message printed to stdout
+# through warning().
 #
 # The following commands are possible; the file extension for the source file
 # in brackets.
 #
# - m4  (.m4): pipe $2.m4 through m4 then write it to $2
# - awk (.in): pipe $2.in through awk then write it to $2
# - cat ($3):  copy $2$3 to $2
 generate() {
     # Get command and target file.
     command="$1"
@@ -105,7 +115,7 @@ generate() {
     # extension.
     if [ x"$command" = xm4 ]; then
         extension=.m4
-    elif [ x"$command" = xawk ]; then
+    elif [ x"$command" = xawk -o x"$command" = xperl ]; then
         extension=.in
     elif [ x"$command" = xcat ]; then
         extension="$1" # is $3 in reality, $1 because of shifting
@@ -117,7 +127,7 @@ generate() {
     fi
 
     # Add warning to file and write a message to stdout.
-    warning "$file" "$file$extension" $command
+    warning "$file" "$file$extension" $command "$*"
     # Generate $file from $file$extension using the given command.
     cat "$file$extension" | $command "$@" >> "$file"
@@ -80,19 +80,29 @@ warning() {
 # in brackets.
 #
-# - m4  (.m4): pipe $2.m4 through m4 then write it to $2
-# - awk (.in): pipe $2.in through awk then write it to $2
-# - cat ($3):  copy $2$3 to $2
+# - m4   (.m4): pipe $2.m4 through m4 then write it to $2
+# - awk  (.in): pipe $2.in through awk then write it to $2
+# - perl (.in): pipe $2.in through perl then write it to $2
+# - cat  ($3):  copy $2$3 to $2
 generate() {
     # Get command and target file.